@@ -1,9 +1,10 @@
 #!/usr/bin/env python3
 # SPDX-License-Identifier: Apache-2.0
 # Copyright 2018-2021 Michael R. Crusoe
-"""CWL Expression refactoring tool for CWL v1.1 ."""
+"""CWL Expression refactoring tool for CWL v1.0 ."""
 import copy
 import hashlib
+import uuid
 from collections.abc import Mapping, MutableSequence, Sequence
 from typing import Any, Optional, Union, cast
 
@@ -11,8 +12,8 @@ from ruamel import yaml
 from schema_salad.sourceline import SourceLine
 from schema_salad.utils import json_dumps
 
-import cwl_utils.parser.cwl_v1_1 as cwl
-import cwl_utils.parser.cwl_v1_1_utils as utils
+import cwl_utils.parser.cwl_v1_0 as cwl
+import cwl_utils.parser.cwl_v1_0_utils as utils
 from cwl_utils.errors import JavascriptException, WorkflowException
 from cwl_utils.expression import do_eval, interpolate
 from cwl_utils.types import CWLObjectType, CWLOutputType
@@ -48,7 +49,7 @@ def escape_expression_field(contents: str) -> str:
 
 
 def clean_type_ids(
-    cwltype: Union[cwl.ArraySchema, cwl.InputRecordSchema]
+    cwltype: Union[cwl.ArraySchema, cwl.InputRecordSchema],
 ) -> Union[cwl.ArraySchema, cwl.InputRecordSchema]:
     """Simplify type identifiers."""
     result = copy.deepcopy(cwltype)
@@ -225,7 +226,7 @@ def traverse(
                     )
                 )
                 wf_inputs.append(
-                    cwl.WorkflowInputParameter(
+                    cwl.InputParameter(
                         id=inp_id,
                         label=inp.label,
                         secondaryFiles=inp.secondaryFiles,
@@ -313,13 +314,13 @@ def load_step(
 
 def generate_etool_from_expr(
     expr: str,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
+    target: Union[cwl.CommandInputParameter, cwl.InputParameter],
     no_inputs: bool = False,
     self_type: Optional[
         Union[
-            cwl.WorkflowInputParameter,
+            cwl.InputParameter,
             cwl.CommandInputParameter,
-            list[Union[cwl.WorkflowInputParameter, cwl.CommandInputParameter]],
+            list[Union[cwl.InputParameter, cwl.CommandInputParameter]],
         ]
     ] = None,  # if the "self" input should be a different type than the "result" output
     extra_processes: Optional[
@@ -335,11 +336,13 @@ def generate_etool_from_expr(
             new_type: Union[
                 list[Union[cwl.ArraySchema, cwl.InputRecordSchema]],
                 Union[cwl.ArraySchema, cwl.InputRecordSchema],
-            ] = [clean_type_ids(t.type_) for t in self_type]
-        else:
+            ] = [clean_type_ids(t.type_) for t in self_type if t.type_]
+        elif self_type.type_:
             new_type = clean_type_ids(self_type.type_)
+        else:
+            raise WorkflowException(f"Don't know how to make type from {self_type!r}.")
         inputs.append(
-            cwl.WorkflowInputParameter(
+            cwl.InputParameter(
                 id="self",
                 label=self_type.label if not isinstance(self_type, list) else None,
                 secondaryFiles=(
@@ -393,6 +396,7 @@ def generate_etool_from_expr(
         find_expressionLib(extra_processes) if extra_processes else None
     )
     return cwl.ExpressionTool(
+        id="_:" + str(uuid.uuid4()),
         inputs=inputs,
         outputs=outputs,
         expression=expression,
@@ -423,7 +427,7 @@ def get_input_for_id(
 def find_expressionLib(
     processes: Sequence[
         Union[cwl.CommandLineTool, cwl.Workflow, cwl.ExpressionTool, cwl.WorkflowStep]
-    ]
+    ],
 ) -> Optional[list[str]]:
     """
     Return the expressionLib from the highest priority InlineJavascriptRequirement.
@@ -443,7 +447,7 @@ def replace_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
+    target: Union[cwl.CommandInputParameter, cwl.InputParameter],
     source: Optional[Union[str, list[Any]]],
     replace_etool: bool = False,
     extra_process: Optional[
@@ -612,9 +616,7 @@ def process_workflow_inputs_and_outputs(
                     raise_type=WorkflowException,
                 ).makeError(TOPLEVEL_FORMAT_EXPR_ERROR.format(param.id.split("#")[-1]))
             if param.secondaryFiles:
-                if hasattr(param.secondaryFiles, "pattern") and get_expression(
-                    param.secondaryFiles.pattern, inputs, EMPTY_FILE
-                ):
+                if get_expression(param.secondaryFiles, inputs, EMPTY_FILE):
                     raise SourceLine(
                         param.loadingOptions.original_doc,
                         "secondaryFiles",
@@ -622,7 +624,7 @@ def process_workflow_inputs_and_outputs(
                     ).makeError(TOPLEVEL_SF_EXPR_ERROR.format(param.id.split("#")[-1]))
                 elif isinstance(param.secondaryFiles, MutableSequence):
                     for index2, entry in enumerate(param.secondaryFiles):
-                        if get_expression(entry.pattern, inputs, EMPTY_FILE):
+                        if get_expression(entry, inputs, EMPTY_FILE):
                             raise SourceLine(
                                 param.loadingOptions.original_doc,
                                 index2,
@@ -674,7 +676,7 @@ def process_workflow_reqs_and_hints(
                             expression = get_expression(envDef.envValue, inputs, None)
                             if expression:
                                 modified = True
-                                target = cwl.WorkflowInputParameter(
+                                target = cwl.InputParameter(
                                     id=None,
                                     type_="string",
                                 )
@@ -705,7 +707,7 @@ def process_workflow_reqs_and_hints(
                         expression = get_expression(this_attr, inputs, None)
                         if expression:
                             modified = True
-                            target = cwl.WorkflowInputParameter(id=None, type_="long")
+                            target = cwl.InputParameter(id=None, type_="long")
                             etool_id = (
                                 "_expression_workflow_ResourceRequirement_{}".format(
                                     attr
@@ -732,7 +734,7 @@ def process_workflow_reqs_and_hints(
                         expression = get_expression(req.listing, inputs, None)
                         if expression:
                             modified = True
-                            target = cwl.WorkflowInputParameter(
+                            target = cwl.InputParameter(
                                 id=None,
                                 type_=cwl.InputArraySchema(
                                     ["File", "Directory"], "array", None, None
@@ -758,7 +760,7 @@ def process_workflow_reqs_and_hints(
                             expression = get_expression(entry, inputs, None)
                             if expression:
                                 modified = True
-                                target = cwl.WorkflowInputParameter(
+                                target = cwl.InputParameter(
                                     id=None,
                                     type_=cwl.InputArraySchema(
                                         ["File", "Directory"], "array", None, None
@@ -801,7 +803,7 @@ def process_workflow_reqs_and_hints(
                                                 or expr_result["class"] == "Directory"
                                             )
                                         ):
-                                            target = cwl.WorkflowInputParameter(
+                                            target = cwl.InputParameter(
                                                 id=None,
                                                 type_=expr_result["class"],
                                             )
@@ -822,7 +824,7 @@ def process_workflow_reqs_and_hints(
                                                 (etool_id, index)
                                             )
                                         elif isinstance(expr_result, str):
-                                            target = cwl.WorkflowInputParameter(
+                                            target = cwl.InputParameter(
                                                 id=None,
                                                 type_=["File"],
                                             )
@@ -865,7 +867,7 @@ def process_workflow_reqs_and_hints(
                                     )
                                     if expression:
                                         modified = True
-                                        target = cwl.WorkflowInputParameter(
+                                        target = cwl.InputParameter(
                                             id=None,
                                             type_="string",
                                         )
@@ -997,7 +999,7 @@ def process_level_reqs(
                         expression = get_expression(envDef.envValue, inputs, None)
                         if expression:
                             modified = True
-                            target = cwl.WorkflowInputParameter(id=None, type_="string")
+                            target = cwl.InputParameter(id=None, type_="string")
                             etool_id = "_expression_{}_EnvVarRequirement_{}".format(
                                 step_name, env_index
                             )
@@ -1021,7 +1023,7 @@ def process_level_reqs(
                     expression = get_expression(this_attr, inputs, None)
                     if expression:
                         modified = True
-                        target = cwl.WorkflowInputParameter(id=None, type_="long")
+                        target = cwl.InputParameter(id=None, type_="long")
                         etool_id = "_expression_{}_ResourceRequirement_{}".format(
                             step_name, attr
                         )
@@ -1048,7 +1050,7 @@ def process_level_reqs(
                         target_type = cwl.InputArraySchema(
                             ["File", "Directory"], "array", None, None
                         )
-                        target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                        target = cwl.InputParameter(id=None, type_=target_type)
                         etool_id = "_expression_{}_InitialWorkDirRequirement".format(
                             step_name
                         )
@@ -1084,7 +1086,7 @@ def process_level_reqs(
                             target_type = cwl.InputArraySchema(
                                 ["File", "Directory"], "array", None, None
                             )
-                            target = cwl.WorkflowInputParameter(
+                            target = cwl.InputParameter(
                                 id=None,
                                 type_=target_type,
                             )
@@ -1141,7 +1143,7 @@ return result; }"""
                                     else:
                                         new_expression = expression
                                     d_target_type = ["File", "Directory"]
-                                    target = cwl.WorkflowInputParameter(
+                                    target = cwl.InputParameter(
                                         id=None,
                                         type_=d_target_type,
                                     )
@@ -1171,7 +1173,7 @@ return result; }"""
                                 )
                                 if expression:
                                     modified = True
-                                    target = cwl.WorkflowInputParameter(
+                                    target = cwl.InputParameter(
                                         id=None,
                                         type_="string",
                                     )
@@ -1249,7 +1251,7 @@ def traverse_CommandLineTool(
                     inp_id = f"_arguments_{index}"
                     etool_id = f"_expression_{step_id}{inp_id}"
                     target_type = "Any"
-                    target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                    target = cwl.InputParameter(id=None, type_=target_type)
                     replace_step_clt_expr_with_etool(
                         expression, etool_id, parent, target, step, replace_etool
                     )
@@ -1275,7 +1277,7 @@ def traverse_CommandLineTool(
                     inp_id = f"_arguments_{index}"
                     etool_id = f"_expression_{step_id}{inp_id}"
                     target_type = "Any"
-                    target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                    target = cwl.InputParameter(id=None, type_=target_type)
                     replace_step_clt_expr_with_etool(
                         expression, etool_id, parent, target, step, replace_etool
                     )
@@ -1301,7 +1303,7 @@ def traverse_CommandLineTool(
                 inp_id = f"_{streamtype}"
                 etool_id = f"_expression_{step_id}{inp_id}"
                 target_type = "string"
-                target = cwl.WorkflowInputParameter(id=None, type_=target_type)
+                target = cwl.InputParameter(id=None, type_=target_type)
                 replace_step_clt_expr_with_etool(
                     expression, etool_id, parent, target, step, replace_etool
                 )
@@ -1341,7 +1343,7 @@ def traverse_CommandLineTool(
                     inp_id = "_{}_glob".format(outp.id.split("#")[-1])
                     etool_id = f"_expression_{step_id}{inp_id}"
                     glob_target_type = ["string", cwl.ArraySchema("string", "array")]
-                    target = cwl.WorkflowInputParameter(id=None, type_=glob_target_type)
+                    target = cwl.InputParameter(id=None, type_=glob_target_type)
                     replace_step_clt_expr_with_etool(
                         expression, etool_id, parent, target, step, replace_etool
                     )
@@ -1377,7 +1379,7 @@ def traverse_CommandLineTool(
                     sub_wf_outputs = cltool_step_outputs_to_workflow_outputs(
                         step, etool_id, outp_id
                     )
-                    self_type = cwl.WorkflowInputParameter(
+                    self_type = cwl.InputParameter(
                         id=None,
                         type_=cwl.InputArraySchema("File", "array", None, None),
                     )
@@ -1423,7 +1425,7 @@ def traverse_CommandLineTool(
                     new_clt_step = copy.copy(
                         step
                     )  # a deepcopy would be convenient, but params2.cwl gives it problems
-                    new_clt_step.id = cast(str, new_clt_step.id).split("#")[-1]
+                    new_clt_step.id = new_clt_step.id.split("#")[-1]
                     new_clt_step.run = copy.copy(step.run)
                     new_clt_step.run.id = None
                     remove_JSReq(new_clt_step.run, skip_command_line1)
@@ -1554,7 +1556,7 @@ def replace_step_clt_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: cwl.WorkflowInputParameter,
+    target: cwl.InputParameter,
     step: cwl.WorkflowStep,
     replace_etool: bool,
     self_name: Optional[str] = None,
@@ -1589,7 +1591,7 @@ def replace_clt_hintreq_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: cwl.WorkflowInputParameter,
+    target: cwl.InputParameter,
     step: cwl.WorkflowStep,
     replace_etool: bool,
     self_name: Optional[str] = None,
@@ -1624,7 +1626,7 @@ def replace_clt_hintreq_expr_with_etool(
 
 def cltool_inputs_to_etool_inputs(
     tool: cwl.CommandLineTool,
-) -> list[cwl.WorkflowInputParameter]:
+) -> list[cwl.InputParameter]:
     """Copy CommandLineTool input objects into the equivalent ExpressionTool input objects."""
     inputs = yaml.comments.CommentedSeq()
     if tool.inputs:
@@ -1632,7 +1634,7 @@ def cltool_inputs_to_etool_inputs(
             clt_inp_id = clt_inp.id.split("#")[-1].split("/")[-1]
             if not clt_inp_id.startswith("_"):
                 inputs.append(
-                    cwl.WorkflowInputParameter(
+                    cwl.InputParameter(
                         id=clt_inp_id,
                         label=clt_inp.label,
                         secondaryFiles=clt_inp.secondaryFiles,
@@ -1688,8 +1690,8 @@ def cltool_step_outputs_to_workflow_outputs(
 
 def generate_etool_from_expr2(
     expr: str,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
-    inputs: Sequence[Union[cwl.WorkflowInputParameter, cwl.CommandInputParameter]],
+    target: cwl.InputParameter,
+    inputs: Sequence[Union[cwl.InputParameter, cwl.CommandInputParameter]],
     self_name: Optional[str] = None,
     process: Optional[Union[cwl.CommandLineTool, cwl.ExpressionTool]] = None,
     extra_processes: Optional[
@@ -1741,6 +1743,7 @@ def generate_etool_from_expr2(
                 x for x in reqs if not isinstance(x, cwl.InitialWorkDirRequirement)
             ]
     return cwl.ExpressionTool(
+        id="_:" + str(uuid.uuid4()),
         inputs=inputs,
         outputs=outputs,
         expression=expression,
@@ -1809,12 +1812,12 @@ def traverse_step(
                     raise WorkflowException("target not found")
                 input_source_id = None
                 source_type: Optional[
-                    Union[list[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]
+                    Union[list[cwl.InputParameter], cwl.InputParameter]
                 ] = None
                 if inp.source:
                     if isinstance(inp.source, MutableSequence):
                         input_source_id = []
-                        source_types: list[cwl.WorkflowInputParameter] = []
+                        source_types: list[cwl.InputParameter] = []
                         for source in inp.source:
                             source_id = source.split("#")[-1]
                             input_source_id.append(source_id)
@@ -1828,7 +1831,7 @@ def traverse_step(
                             else:
                                 if temp_type not in source_types:
                                     source_types.append(temp_type)
-                        source_type = cwl.WorkflowInputParameter(
+                        source_type = cwl.InputParameter(
                             id=None,
                             type_=cwl.ArraySchema(source_types, "array"),
                         )
@@ -1895,10 +1898,10 @@ def traverse_step(
     return modified
 
 
-def workflow_step_to_WorkflowInputParameters(
+def workflow_step_to_InputParameters(
     step_ins: list[cwl.WorkflowStepInput], parent: cwl.Workflow, except_in_id: str
-) -> list[cwl.WorkflowInputParameter]:
-    """Create WorkflowInputParameters to match the given WorkflowStep inputs."""
+) -> list[cwl.InputParameter]:
+    """Create InputParameters to match the given WorkflowStep inputs."""
     params = []
     for inp in step_ins:
         if not inp.id:
@@ -1910,10 +1913,18 @@ def workflow_step_to_WorkflowInputParameters(
             )
             if isinstance(param, list):
                 for p in param:
+                    if not p.type_:
+                        raise WorkflowException(
+                            f"Don't know how to get type id for {p!r}."
+                        )
                     p.id = inp_id
                     p.type_ = clean_type_ids(p.type_)
                     params.append(p)
             else:
+                if not param.type_:
+                    raise WorkflowException(
+                        f"Don't know how to get type id for {param!r}."
+                    )
                 param.id = inp_id
                 param.type_ = clean_type_ids(param.type_)
                 params.append(param)
@@ -1924,26 +1935,24 @@ def replace_step_valueFrom_expr_with_etool(
     expr: str,
     name: str,
     workflow: cwl.Workflow,
-    target: Union[cwl.CommandInputParameter, cwl.WorkflowInputParameter],
+    target: Union[cwl.CommandInputParameter, cwl.InputParameter],
     step: cwl.WorkflowStep,
     step_inp: cwl.WorkflowStepInput,
     original_process: Union[cwl.CommandLineTool, cwl.ExpressionTool],
     original_step_ins: list[cwl.WorkflowStepInput],
     source: Optional[Union[str, list[str]]],
     replace_etool: bool,
-    source_type: Optional[
-        Union[cwl.WorkflowInputParameter, list[cwl.WorkflowInputParameter]]
-    ] = None,
+    source_type: Optional[Union[cwl.InputParameter, list[cwl.InputParameter]]] = None,
 ) -> None:
     """Replace a WorkflowStep level 'valueFrom' expression with a sibling ExpressionTool step."""
     if not step_inp.id:
         raise WorkflowException(f"Missing id in {step_inp}.")
     step_inp_id = step_inp.id.split("/")[-1]
-    etool_inputs = workflow_step_to_WorkflowInputParameters(
+    etool_inputs = workflow_step_to_InputParameters(
         original_step_ins, workflow, step_inp_id
     )
     if source:
-        source_param = cwl.WorkflowInputParameter(id="self", type_="Any")
+        source_param = cwl.InputParameter(id="self", type_="Any")
         # TODO: would be nicer to derive a proper type; but in the face of linkMerge, this is easier for now
         etool_inputs.append(source_param)
     temp_etool = generate_etool_from_expr2(
@@ -1971,8 +1980,6 @@ def replace_step_valueFrom_expr_with_etool(
     if source:
         wf_step_inputs.append(cwl.WorkflowStepInput(id="self", source=step_inp.source))
     for wf_step_input in wf_step_inputs:
-        if not wf_step_input.id:
-            continue
         wf_step_input.id = wf_step_input.id.split("/")[-1]
         if wf_step_input.valueFrom:
             wf_step_input.valueFrom = None
