@@ -3,5 +3,5 @@ var foo = function(x) {
 }
 
 var bar = function(n, x) {
-    return `{n} engineers walk into a {x}`
-}
\ No newline at end of file
+    return n + " engineers walk into a " + x
+}
