@@ -1,17 +1,11 @@
-from pathlib import Path
-
 from cwl_utils.parser import cwl_v1_0, cwl_v1_1, cwl_v1_2, load_document_by_uri
 
-from .util import get_data
+from .util import get_path
 
 
 def test_cuda_requirement_v1_0() -> None:
     """Test that CUDARequirement objects are correctly loaded for CWL v1.0."""
-    uri = (
-        Path(get_data("testdata/extensions/cuda-requirement_v1_0.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/cuda-requirement_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.CUDARequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -20,11 +14,7 @@ def test_cuda_requirement_v1_0() -> None:
 
 def test_cuda_requirement_v1_1() -> None:
     """Test that CUDARequirement objects are correctly loaded for CWL v1.1."""
-    uri = (
-        Path(get_data("testdata/extensions/cuda-requirement_v1_1.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/cuda-requirement_v1_1.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_1.CUDARequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -33,11 +23,7 @@ def test_cuda_requirement_v1_1() -> None:
 
 def test_cuda_requirement_v1_2() -> None:
     """Test that CUDARequirement objects are correctly loaded for CWL v1.2."""
-    uri = (
-        Path(get_data("testdata/extensions/cuda-requirement_v1_2.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/cuda-requirement_v1_2.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_2.CUDARequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -46,11 +32,7 @@ def test_cuda_requirement_v1_2() -> None:
 
 def test_load_listing_requirement_v1_0() -> None:
     """Test that LoadListingRequirement objects are correctly loaded for CWL v1.0."""
-    uri = (
-        Path(get_data("testdata/extensions/load-listing-requirement_v1_0.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/load-listing-requirement_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.LoadListingRequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -59,11 +41,7 @@ def test_load_listing_requirement_v1_0() -> None:
 
 def test_loop_v1_2() -> None:
     """Test that Loop and LoopInput objects are correctly loaded for CWL v1.2."""
-    uri = (
-        Path(get_data("testdata/extensions/single-var-loop_v1_2.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/single-var-loop_v1_2.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     cwl_step = next(iter(cwl_obj.steps))
     loop_req = next(iter(cwl_step.requirements))
@@ -75,11 +53,7 @@ def test_loop_v1_2() -> None:
 
 def test_inplace_update_requirement_v1_0() -> None:
     """Test that InplaceUpdateRequirement objects are correctly loaded for CWL v1.0."""
-    uri = (
-        Path(get_data("testdata/extensions/inplace-update-requirement_v1_0.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/inplace-update-requirement_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(
         next(iter(cwl_obj.requirements)), cwl_v1_0.InplaceUpdateRequirement
@@ -90,11 +64,7 @@ def test_inplace_update_requirement_v1_0() -> None:
 
 def test_mpi_requirement_v1_0() -> None:
     """Test that MPIRequirement objects are correctly loaded for CWL v1.0."""
-    uri = (
-        Path(get_data("testdata/extensions/mpi-requirement_v1_0.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/mpi-requirement_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.MPIRequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -103,11 +73,7 @@ def test_mpi_requirement_v1_0() -> None:
 
 def test_mpi_requirement_v1_1() -> None:
     """Test that MPIRequirement objects are correctly loaded for CWL v1.1."""
-    uri = (
-        Path(get_data("testdata/extensions/mpi-requirement_v1_1.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/mpi-requirement_v1_1.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_1.MPIRequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -116,11 +82,7 @@ def test_mpi_requirement_v1_1() -> None:
 
 def test_mpi_requirement_v1_2() -> None:
     """Test that MPIRequirement objects are correctly loaded for CWL v1.2."""
-    uri = (
-        Path(get_data("testdata/extensions/mpi-requirement_v1_2.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/mpi-requirement_v1_2.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_2.MPIRequirement)
     cwl_dict = cwl_obj.save(top=True)
@@ -129,9 +91,7 @@ def test_mpi_requirement_v1_2() -> None:
 
 def test_network_access_v1_0() -> None:
     """Test that NetworkAccess objects are correctly loaded for CWL v1.0."""
-    uri = (
-        Path(get_data("testdata/extensions/network-access_v1_0.cwl")).resolve().as_uri()
-    )
+    uri = get_path("testdata/extensions/network-access_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.NetworkAccess)
     cwl_dict = cwl_obj.save(top=True)
@@ -140,11 +100,7 @@ def test_network_access_v1_0() -> None:
 
 def test_process_generator_v1_0() -> None:
     """Test that ProcessGenerator objects are correctly loaded for CWL v1.0."""
-    uri = (
-        Path(get_data("testdata/extensions/process-generator_v1_0.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/process-generator_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(cwl_obj, cwl_v1_0.ProcessGenerator)
     cwl_dict = cwl_obj.save(top=True)
@@ -153,11 +109,7 @@ def test_process_generator_v1_0() -> None:
 
 def test_process_generator_v1_1() -> None:
     """Test that ProcessGenerator objects are correctly loaded for CWL v1.1."""
-    uri = (
-        Path(get_data("testdata/extensions/process-generator_v1_1.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/process-generator_v1_1.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(cwl_obj, cwl_v1_1.ProcessGenerator)
     cwl_dict = cwl_obj.save(top=True)
@@ -166,11 +118,7 @@ def test_process_generator_v1_1() -> None:
 
 def test_process_generator_v1_2() -> None:
     """Test that ProcessGenerator objects are correctly loaded for CWL v1.2."""
-    uri = (
-        Path(get_data("testdata/extensions/process-generator_v1_2.cwl"))
-        .resolve()
-        .as_uri()
-    )
+    uri = get_path("testdata/extensions/process-generator_v1_2.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(cwl_obj, cwl_v1_2.ProcessGenerator)
     cwl_dict = cwl_obj.save(top=True)
@@ -179,7 +127,7 @@ def test_process_generator_v1_2() -> None:
 
 def test_secrets_v1_0() -> None:
     """Test that Secrets objects are correctly loaded for CWL v1.0."""
-    uri = Path(get_data("testdata/extensions/secrets_v1_0.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/secrets_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.Secrets)
     cwl_dict = cwl_obj.save(top=True)
@@ -188,7 +136,7 @@ def test_secrets_v1_0() -> None:
 
 def test_secrets_v1_1() -> None:
     """Test that Secrets objects are correctly loaded for CWL v1.1."""
-    uri = Path(get_data("testdata/extensions/secrets_v1_1.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/secrets_v1_1.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_1.Secrets)
     cwl_dict = cwl_obj.save(top=True)
@@ -197,7 +145,7 @@ def test_secrets_v1_1() -> None:
 
 def test_secrets_v1_2() -> None:
     """Test that Secrets objects are correctly loaded for CWL v1.2."""
-    uri = Path(get_data("testdata/extensions/secrets_v1_2.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/secrets_v1_2.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_2.Secrets)
     cwl_dict = cwl_obj.save(top=True)
@@ -206,7 +154,7 @@ def test_secrets_v1_2() -> None:
 
 def test_shm_size_v1_0() -> None:
     """Test that ShmSize objects are correctly loaded for CWL v1.0."""
-    uri = Path(get_data("testdata/extensions/shm-size_v1_0.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/shm-size_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.ShmSize)
     cwl_dict = cwl_obj.save(top=True)
@@ -215,7 +163,7 @@ def test_shm_size_v1_0() -> None:
 
 def test_shm_size_v1_1() -> None:
     """Test that ShmSize objects are correctly loaded for CWL v1.1."""
-    uri = Path(get_data("testdata/extensions/shm-size_v1_1.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/shm-size_v1_1.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_1.ShmSize)
     cwl_dict = cwl_obj.save(top=True)
@@ -224,7 +172,7 @@ def test_shm_size_v1_1() -> None:
 
 def test_shm_size_v1_2() -> None:
     """Test that ShmSize objects are correctly loaded for CWL v1.2."""
-    uri = Path(get_data("testdata/extensions/shm-size_v1_2.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/shm-size_v1_2.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_2.ShmSize)
     cwl_dict = cwl_obj.save(top=True)
@@ -233,7 +181,7 @@ def test_shm_size_v1_2() -> None:
 
 def test_time_limit_v1_0() -> None:
     """Test that TimeLimit objects are correctly loaded for CWL v1.0."""
-    uri = Path(get_data("testdata/extensions/time-limit_v1_0.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/time-limit_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.TimeLimit)
     cwl_dict = cwl_obj.save(top=True)
@@ -242,7 +190,7 @@ def test_time_limit_v1_0() -> None:
 
 def test_work_reuse_v1_0() -> None:
     """Test that WorkReuse objects are correctly loaded for CWL v1.0."""
-    uri = Path(get_data("testdata/extensions/work-reuse_v1_0.cwl")).resolve().as_uri()
+    uri = get_path("testdata/extensions/work-reuse_v1_0.cwl").as_uri()
     cwl_obj = load_document_by_uri(uri)
     assert isinstance(next(iter(cwl_obj.requirements)), cwl_v1_0.WorkReuse)
     cwl_dict = cwl_obj.save(top=True)
